Package: ocs4R
Version: 0.3.1
Date: 2026-04-29
Title: Interface to Open Collaboration Services (OCS) REST API
Authors@R: c(
  person("Emmanuel", "Blondel", role = c("aut", "cre"), email = "emmanuel.blondel1@gmail.com", comment = c(ORCID = "0000-0002-5870-5762")))
Maintainer: Emmanuel Blondel <emmanuel.blondel1@gmail.com>
Depends: R (>= 3.3.0), methods
Imports: R6, openssl, curl,httr, jsonlite, XML, keyring
Suggests: testthat
Description: Provides an Interface to Open Collaboration Services 'OCS' (<https://www.open-collaboration-services.org/>) REST API.
License: MIT + file LICENSE
URL: https://github.com/eblondel/ocs4R
BugReports: https://github.com/eblondel/ocs4R/issues
LazyLoad: yes
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-04-29 21:33:36 UTC; emman
Author: Emmanuel Blondel [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5870-5762>)
Repository: CRAN
Date/Publication: 2026-04-29 22:10:02 UTC
Built: R 4.5.2; ; 2026-05-01 18:04:23 UTC; unix
