# Generated by roxygen2: do not edit by hand

export(ocs4RLogger)
export(ocsApiSharingManager)
export(ocsApiUserProvisioningManager)
export(ocsApiWebdavManager)
export(ocsManager)
export(ocsRequest)
import(XML)
import(curl)
import(jsonlite)
import(keyring)
import(methods)
importFrom(R6,R6Class)
importFrom(httr,DELETE)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,PUT)
importFrom(httr,add_headers)
importFrom(httr,authenticate)
importFrom(httr,content)
importFrom(httr,cookies)
importFrom(httr,handle)
importFrom(httr,headers)
importFrom(httr,http_status)
importFrom(httr,status_code)
importFrom(httr,upload_file)
importFrom(httr,with_verbose)
importFrom(openssl,base64_encode)
