[![Build Status](https://github.com/eblondel/ocs4R/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/ocs4R/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/ocs4R)](https://cran.r-project.org/package=ocs4R)
[![cran checks](https://badges.cranchecks.info/worst/ocs4R.svg)](https://cran.r-project.org/web/checks/check_results_ocs4R.html)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.3.1-blue.svg)](https://github.com/eblondel/ocs4R)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3663614.svg)](https://doi.org/10.5281/zenodo.3663614)

**ocs4R – R Interface to Open Collaboration Services (OCS) REST APIs**

``ocs4R`` provides a R interface to the [Open Collaboration Services (OCS)](https://www.open-collaboration-services.org) REST APIs. ``ocs4R`` includes support for the below APIs:

* OCS Webdav API
* OCS Share API
* OCS User Provisioning API

``ocs4R`` constitutes the generic R client to access to OCS-compliant cloud platforms such as [ownCloud](https://owncloud.com/) and [Nextcloud](https://nextcloud.com/), either directly using [ocs4R](https://github.com/eblondel/ocs4R) or through product-specific ``ocs4R`` wrappers such as [ownCloud4R](https://github.com/eblondel/ownCloud4R) and [nextCloud4R](https://github.com/eblondel/nextCloud4R)

<a name="package_status"/>

Please check the [online documentation](https://github.com/eblondel/ocs4R/wiki) for more details!

## Sponsors

For ocs4R sponsoring/funding new developments, enhancements, support requests, please contact me by [e-mail](mailto:eblondel.pro@gmail.com).

## Citation

You can get the preferred citation by using the ``ocs4R`` Document Object Identifier (DOI): [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3663614.svg)](https://doi.org/10.5281/zenodo.3663614)

We thank in advance people that use ``ocs4R`` for citing it in their work / publication(s). 
