#' @name ocs4R
#' @aliases ocs4R-package
#' @aliases ocs4R
#' 
#' @importFrom R6 R6Class
#' @importFrom openssl base64_encode
#' @import methods
#' @import curl
#' @importFrom httr DELETE
#' @importFrom httr GET
#' @importFrom httr POST
#' @importFrom httr PUT
#' @importFrom httr add_headers
#' @importFrom httr authenticate
#' @importFrom httr content
#' @importFrom httr headers
#' @importFrom httr cookies
#' @importFrom httr http_status
#' @importFrom httr status_code
#' @importFrom httr with_verbose
#' @importFrom httr upload_file
#' @importFrom httr handle
#' @import jsonlite
#' @import XML
#' @import keyring
#' 
#' @title Interface to 'OCS' REST API
#' @description Provides an Interface to 'OCS' (<https://www.open-collaboration-services.org/>) REST API.
#'  
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"
