% Generated by roxygen2: do not edit by hand % Please edit documentation in R/ocsApiWebdavManager.R \docType{class} \name{ocsApiWebdavManager} \alias{ocsApiWebdavManager} \title{ocsApiWebdavManager} \format{ \code{\link[R6]{R6Class}} object. } \value{ Object of \code{\link[R6]{R6Class}} for modelling an ocsManager for Webdav API } \description{ ocsApiWebdavManager ocsApiWebdavManager } \author{ Emmanuel Blondel } \keyword{api} \keyword{manager} \keyword{ocs} \keyword{webdav} \section{Super classes}{ \code{\link[ocs4R:ocs4RLogger]{ocs4R::ocs4RLogger}} -> \code{\link[ocs4R:ocsManager]{ocs4R::ocsManager}} -> \code{ocsApiWebdavManager} } \section{Methods}{ \subsection{Public methods}{ \itemize{ \item \href{#method-ocsApiWebdavManager-new}{\code{ocsApiWebdavManager$new()}} \item \href{#method-ocsApiWebdavManager-getWebdavRoot}{\code{ocsApiWebdavManager$getWebdavRoot()}} \item \href{#method-ocsApiWebdavManager-listFiles}{\code{ocsApiWebdavManager$listFiles()}} \item \href{#method-ocsApiWebdavManager-makeCollection}{\code{ocsApiWebdavManager$makeCollection()}} \item \href{#method-ocsApiWebdavManager-uploadFile}{\code{ocsApiWebdavManager$uploadFile()}} \item \href{#method-ocsApiWebdavManager-deleteFile}{\code{ocsApiWebdavManager$deleteFile()}} \item \href{#method-ocsApiWebdavManager-downloadFile}{\code{ocsApiWebdavManager$downloadFile()}} \item \href{#method-ocsApiWebdavManager-getPublicFile}{\code{ocsApiWebdavManager$getPublicFile()}} \item \href{#method-ocsApiWebdavManager-clone}{\code{ocsApiWebdavManager$clone()}} } } \if{html}{\out{
Inherited methods

- `ocs4R::ocs4RLogger$ERROR()`
- `ocs4R::ocs4RLogger$INFO()`
- `ocs4R::ocs4RLogger$WARN()`
- `ocs4R::ocs4RLogger$getClass()`
- `ocs4R::ocs4RLogger$getClassName()`
- `ocs4R::ocs4RLogger$logger()`
- `ocs4R::ocsManager$connect()`
- `ocs4R::ocsManager$getAPISharingManager()`
- `ocs4R::ocsManager$getAPIUserProvisioningManager()`
- `ocs4R::ocsManager$getAPIWebdavManager()`
- `ocs4R::ocsManager$getCapabilities()`
- `ocs4R::ocsManager$getVersion()`

}} \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-new}{}}} \subsection{Method \code{new()}}{ Initialize manager \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$new(url, user, pwd, logger = NULL, keyring_backend = NULL)}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{url}}{url} \item{\code{user}}{user} \item{\code{pwd}}{pwd} \item{\code{logger}}{logger} \item{\code{keyring_backend}}{backend to use with \pkg{keyring}. Default is \code{NULL}} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-getWebdavRoot}{}}} \subsection{Method \code{getWebdavRoot()}}{ Get the 'ocs' WebDAV root URL \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$getWebdavRoot()}\if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-listFiles}{}}} \subsection{Method \code{listFiles()}}{ WebDAV method to list folders/files given a relative path. The relative path is set to \code{"/"} by default, which corresponds to the root of the 'ocs' repository. \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$listFiles(relPath = "/")}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{relPath}}{relative path} } \if{html}{\out{
}} } \subsection{Returns}{ the list of files } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-makeCollection}{}}} \subsection{Method \code{makeCollection()}}{ WebDAV method to make a collection. By default \code{relPath} is set to \code{"/"} (root). The \code{name} is the name of the new collection to be created. The function is recursive in the sense that a \code{name} can be provided as relative path of a collection tree (eg \code{newfolder1/newfolder2/newfolder3}), the function will create recursively as many collections are handled in the name. \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$makeCollection(name, relPath = "/")}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{name}}{name} \item{\code{relPath}}{relative path} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-uploadFile}{}}} \subsection{Method \code{uploadFile()}}{ WebDAV method to upload a file. By default \code{relPath} is set to \code{"/"} (root). \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$uploadFile( filename, relPath = "/", delete_if_existing = FALSE )}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{filename}}{file name} \item{\code{relPath}}{relative path} \item{\code{delete_if_existing}}{delete if existing file? Default is \code{FALSE}} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-deleteFile}{}}} \subsection{Method \code{deleteFile()}}{ WebDAV method to delete a file. By default \code{relPath} is set to \code{"/"} (root). \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$deleteFile(filename, relPath = "/")}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{filename}}{file name} \item{\code{relPath}}{relative path} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-downloadFile}{}}} \subsection{Method \code{downloadFile()}}{ Downloads a file \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$downloadFile(relPath, filename, outdir = ".")}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{relPath}}{relative path} \item{\code{filename}}{file name} \item{\code{outdir}}{the out directory where to download the file} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-getPublicFile}{}}} \subsection{Method \code{getPublicFile()}}{ Get details of a shared public file given its share token \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$getPublicFile(share_token)}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{share_token}}{the share token} } \if{html}{\out{
}} } } \if{html}{\out{

}} \if{html}{\out{}} \if{latex}{\out{\hypertarget{method-ocsApiWebdavManager-clone}{}}} \subsection{Method \code{clone()}}{ The objects of this class are cloneable with this method. \subsection{Usage}{ \if{html}{\out{
}}\preformatted{ocsApiWebdavManager$clone(deep = FALSE)}\if{html}{\out{
}} } \subsection{Arguments}{ \if{html}{\out{
}} \describe{ \item{\code{deep}}{Whether to make a deep clone.} } \if{html}{\out{
}} } } }